@@ -4,8 +4,6 @@ Created on 28 Sep 2020
 @author: Jade Page (jade.page@southcoastscience.com)
 """
 
-import boto3
-
 from botocore.exceptions import ClientError
 from collections import OrderedDict
 
@@ -23,31 +21,6 @@ class S3Manager(object):
     classdocs
     """
 
-    # ----------------------------------------------------------------------------------------------------------------
-
-    @classmethod
-    def create_clients(cls, access_key=None):
-        if access_key:
-            client = boto3.client(
-                's3',
-                aws_access_key_id=access_key.key_id,
-                aws_secret_access_key=access_key.secret_key,
-                region_name='us-west-2'
-            )
-            resource_client = boto3.resource(
-                's3',
-                aws_access_key_id=access_key.key_id,
-                aws_secret_access_key=access_key.secret_key,
-                region_name='us-west-2'
-            )
-
-        else:
-            client = boto3.client('s3', region_name='us-west-2')
-            resource_client = boto3.resource('s3', region_name='us-west-2')
-
-        return client, resource_client
-
-
     # ----------------------------------------------------------------------------------------------------------------
 
     def __init__(self, client, resource_client):
