@@ -31,9 +31,9 @@ class MQTTConf(PersistentJSONable):
     # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
-    def construct_from_jdict(cls, jdict):
+    def construct_from_jdict(cls, jdict, default=True):
         if not jdict:
-            return MQTTConf(False, None, False)
+            return None if default is None else MQTTConf(False, None, False)
 
         inhibit_publishing = jdict.get('inhibit-publishing', False)
         report_file = jdict.get('report-file', None)
@@ -53,6 +53,15 @@ class MQTTConf(PersistentJSONable):
         self.__debug = bool(debug)                                          # DEBUG log level
 
 
+    def __eq__(self, other):
+        try:
+            return self.inhibit_publishing == other.inhibit_publishing and self.report_file == other.report_file and \
+                   self.debug == other.debug
+
+        except (TypeError, AttributeError):
+            return False
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     @property
