@@ -50,6 +50,16 @@ class JSONable(object):
 
     _INDENT = 4
 
+    # ----------------------------------------------------------------------------------------------------------------
+
+    @classmethod
+    def loads(cls, jstr):
+        try:
+            return json.loads(jstr)
+        except json.decoder.JSONDecodeError:
+            raise ValueError(jstr.strip())
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     def as_list(self, jlist):
@@ -81,19 +91,17 @@ class JSONReport(JSONable):
     # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
-    def load(cls, filename):
+    def load(cls, filename, default=True):
         if filename is None:
             return None
 
         if not os.path.isfile(filename):
-            return cls.construct_from_jdict(None)
+            return cls.construct_from_jdict(None, default=default)
 
         with open(filename, 'r') as f:
             jstr = f.read()
 
-        jdict = json.loads(jstr.strip())
-
-        return cls.construct_from_jdict(jdict)
+        return cls.construct_from_jdict(cls.loads(jstr), default=default)
 
 
     @classmethod
@@ -106,7 +114,7 @@ class JSONReport(JSONable):
 
     @classmethod
     @abstractmethod
-    def construct_from_jdict(cls, jdict):
+    def construct_from_jdict(cls, jdict, default=True):
         return JSONReport()
 
 
@@ -195,18 +203,18 @@ class PersistentJSONable(AbstractPersistentJSONable):
 
 
     @classmethod
-    def load(cls, manager, encryption_key=None):
+    def load(cls, manager, encryption_key=None, default=True):
         try:
             dirname, filename = cls.persistence_location()
         except NotImplementedError:
             return None
 
         if not manager.exists(dirname, filename):
-            return cls.construct_from_jdict(None)
+            return cls.construct_from_jdict(None, default=default)
 
         jstr = manager.load(dirname, filename, encryption_key=encryption_key)
 
-        return cls.construct_from_jdict(json.loads(jstr))
+        return cls.construct_from_jdict(cls.loads(jstr), default=default)
 
 
     @classmethod
@@ -221,16 +229,12 @@ class PersistentJSONable(AbstractPersistentJSONable):
 
     # ----------------------------------------------------------------------------------------------------------------
 
-    # noinspection PyUnusedLocal
-
     @classmethod
     @abstractmethod
-    def construct_from_jdict(cls, jdict):
+    def construct_from_jdict(cls, jdict, default=True):
         return PersistentJSONable()
 
 
-    # noinspection PyUnusedLocal
-
     @classmethod
     @abstractmethod
     def persistence_location(cls):
@@ -266,18 +270,18 @@ class MultiPersistentJSONable(AbstractPersistentJSONable):
 
 
     @classmethod
-    def load(cls, manager, name=None, encryption_key=None):
+    def load(cls, manager, name=None, encryption_key=None, default=True):
         try:
             dirname, filename = cls.persistence_location(name)
         except NotImplementedError:
             return None
 
         if not manager.exists(dirname, filename):
-            return cls.construct_from_jdict(None, name=name)
+            return cls.construct_from_jdict(None, name=name, default=default)
 
         jstr = manager.load(dirname, filename, encryption_key=encryption_key)
 
-        return cls.construct_from_jdict(json.loads(jstr), name=name)
+        return cls.construct_from_jdict(cls.loads(jstr), name=name, default=default)
 
 
     @classmethod
@@ -292,16 +296,12 @@ class MultiPersistentJSONable(AbstractPersistentJSONable):
 
     # ----------------------------------------------------------------------------------------------------------------
 
-    # noinspection PyUnusedLocal
-
     @classmethod
     @abstractmethod
-    def construct_from_jdict(cls, jdict, name=None):
+    def construct_from_jdict(cls, jdict, name=None, default=True):
         return PersistentJSONable()
 
 
-    # noinspection PyUnusedLocal
-
     @classmethod
     @abstractmethod
     def persistence_location(cls, name):
