@@ -32,7 +32,7 @@ class A4Calib(SensorCalib):
     # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
-    def construct_from_jdict(cls, jdict):
+    def construct_from_jdict(cls, jdict, default=True):
         if not jdict:
             return None
 
@@ -55,7 +55,6 @@ class A4Calib(SensorCalib):
         we_sens_mv = jdict.get('we_sensitivity_mv_ppb')
         we_no2_x_sens_mv = jdict.get('we_cross_sensitivity_no2_mv_ppb')
 
-
         return cls(serial_number, sensor_type, we_elc_mv, we_cal_mv, we_tot_mv, ae_elc_mv, ae_cal_mv, ae_tot_mv,
                    we_sens_na, we_x_sens_na, pcb_gain, we_sens_mv, we_no2_x_sens_mv)
 
@@ -86,6 +85,21 @@ class A4Calib(SensorCalib):
         self.__we_no2_x_sens_mv = Datum.float(we_no2_x_sens_mv, 3)  # WE cross-sensitivity                  mV / ppb
 
 
+    def __eq__(self, other):
+        try:
+            return self.serial_number == other.serial_number and self.sensor_type == other.sensor_type and \
+                   self.we_elc_mv == other.we_elc_mv and self.we_cal_mv == other.we_cal_mv and \
+                   self.we_tot_mv == other.we_tot_mv and \
+                   self.ae_elc_mv == other.ae_elc_mv and self.ae_cal_mv == other.ae_cal_mv and \
+                   self.ae_tot_mv == other.ae_tot_mv and \
+                   self.we_sens_na == other.we_sens_na and self.we_x_sens_na == other.we_x_sens_na and \
+                   self.pcb_gain == other.pcb_gain and \
+                   self.we_sens_mv == other.we_sens_mv and self.we_no2_x_sens_mv == other.we_no2_x_sens_mv
+
+        except (TypeError, AttributeError):
+            return False
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     def set_defaults(self):
