@@ -44,13 +44,13 @@ class GasesSample(Sample):
     __VOC_FIELDS = ['VOC']
 
     @classmethod
-    def construct_from_jdict(cls, jdict):
+    def construct_from_jdict(cls, jdict, default=True):
         if not jdict:
             return None
 
         # Sample...
-        tag = jdict.get('tag')
         rec = LocalizedDatetime.construct_from_jdict(jdict.get('rec'))
+        tag = jdict.get('tag')
         val = jdict.get('val')
         exegeses = jdict.get('exg')
 
