@@ -24,7 +24,7 @@ class Sample(JSONable):
     # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
-    def construct_from_jdict(cls, jdict):
+    def construct_from_jdict(cls, jdict, default=True):
         if not jdict:
             return None
 
@@ -56,13 +56,14 @@ class Sample(JSONable):
     def as_json(self):
         jdict = OrderedDict()
 
+        jdict['rec'] = None if self.rec is None else self.rec.as_iso8601(self.INCLUDE_MILLIS)
+
         if self.tag is not None:
             jdict['tag'] = self.tag
 
         if self.src is not None:
             jdict['src'] = self.src
 
-        jdict['rec'] = None if self.rec is None else self.rec.as_iso8601(self.INCLUDE_MILLIS)
         jdict['val'] = self.values
 
         if self.exegeses:
@@ -83,6 +84,11 @@ class Sample(JSONable):
         return self.__rec
 
 
+    @rec.setter
+    def rec(self, rec):
+        self.__rec = rec
+
+
     @property
     def src(self):
         return self.__src
