@@ -33,13 +33,13 @@ class StatusSample(Sample):
     """
 
     @classmethod
-    def construct_from_jdict(cls, jdict):
+    def construct_from_jdict(cls, jdict, default=True):
         if not jdict:
             return None
 
         # Sample...
-        tag = jdict.get('tag')
         rec = LocalizedDatetime.construct_from_jdict(jdict.get('rec'))
+        tag = jdict.get('tag')
         val = jdict.get('val')
 
         # StatusSample...
