@@ -45,9 +45,9 @@ class Schedule(PersistentJSONable):
     # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
-    def construct_from_jdict(cls, jdict):
+    def construct_from_jdict(cls, jdict, default=True):
         if not jdict:
-            return Schedule(OrderedDict())
+            return None if default is None else Schedule(OrderedDict())
 
         items = OrderedDict()
 
@@ -66,6 +66,21 @@ class Schedule(PersistentJSONable):
         self.__items = items                # dict of name: ScheduleItem
 
 
+    def __eq__(self, other):
+        try:
+            if list(self.names()) != list(other.names()):
+                return False
+
+            for name in self.names():
+                if self.item(name) != other.item(name):
+                    return False
+
+            return True
+
+        except (TypeError, AttributeError):
+            return False
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     def is_valid(self):
@@ -110,6 +125,10 @@ class Schedule(PersistentJSONable):
 
     # ----------------------------------------------------------------------------------------------------------------
 
+    def names(self):
+        return self.__items.keys()
+
+
     @property
     def items(self):
         return self.__items.values()
@@ -167,6 +186,15 @@ class ScheduleItem(JSONable):
         self.__tally = int(tally)                                   # int       number of samples per report
 
 
+    def __eq__(self, other):
+        try:
+            return self.name == other.name and self.interval == other.interval and \
+                   self.tally == other.tally
+
+        except (TypeError, AttributeError):
+            return False
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     def is_valid(self):
